hexify_index_to_lonlat: Convert index string to longitude/latitude

View source: R/hexify_index.R

hexify_index_to_lonlatR Documentation

Convert index string to longitude/latitude

Description

Returns the cell center coordinates for a given index.

Usage

hexify_index_to_lonlat(
  index,
  aperture = 3L,
  index_type = c("auto", "z3", "z7", "zorder")
)

Arguments

index

Index string

aperture

Aperture (3, 4, or 7)

index_type

Index encoding. Default "auto" infers from aperture.

Value

Named numeric vector with lon and lat in degrees

See Also

Other hierarchical index: hexify_cell_to_index(), hexify_compare_indices(), hexify_default_index_type(), hexify_get_children(), hexify_get_parent(), hexify_get_resolution(), hexify_index_to_cell(), hexify_is_valid_index_type(), hexify_lonlat_to_index(), hexify_z7_canonical()

Examples

coords <- hexify_index_to_lonlat("0012012", aperture = 3)

hexify documentation built on March 1, 2026, 1:07 a.m.