View source: R/hexify_conversions.R
| hexify_quad_ij_to_icosa_tri | R Documentation |
Converts Quad IJ coordinates to icosahedral triangle coordinates. This is useful for understanding where a cell is located on the icosahedral projection.
hexify_quad_ij_to_icosa_tri(quad, i, j, resolution, aperture = 3L)
quad |
Quad number (0-11), integer or vector |
i |
Cell index along first axis, integer or vector |
j |
Cell index along second axis, integer or vector |
resolution |
Grid resolution level (0-30) |
aperture |
Grid aperture: 3, 4, or 7 |
Equivalent to 'dggridR' dgQ2DI_to_PROJTRI().
Data frame with columns:
icosa_triangle_face |
Triangle face number (0-19) |
icosa_triangle_x |
X coordinate on triangle face |
icosa_triangle_y |
Y coordinate on triangle face |
hexify_icosa_tri_to_quad_ij for the inverse,
hexify_cell_to_icosa_tri for conversion from cell ID
Other coordinate conversion:
hexify_cell_id_to_quad_ij(),
hexify_cell_to_icosa_tri(),
hexify_cell_to_lonlat(),
hexify_cell_to_plane(),
hexify_cell_to_quad_ij(),
hexify_cell_to_quad_xy(),
hexify_grid_cell_to_lonlat(),
hexify_grid_to_cell(),
hexify_icosa_tri_to_plane(),
hexify_icosa_tri_to_quad_ij(),
hexify_icosa_tri_to_quad_xy(),
hexify_lonlat_to_cell(),
hexify_lonlat_to_plane(),
hexify_lonlat_to_quad_ij(),
hexify_quad_ij_to_cell(),
hexify_quad_ij_to_xy(),
hexify_quad_xy_to_cell(),
hexify_quad_xy_to_icosa_tri(),
hexify_roundtrip_test()
# Get triangle coordinates for a Quad IJ position
result <- hexify_quad_ij_to_icosa_tri(quad = 1, i = 100, j = 50,
resolution = 10, aperture = 3)
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.