| dgverify | R Documentation |
Validates that a grid object has all required fields and valid values. This function is called internally by most hexify functions to ensure grid integrity.
dgverify(dggs)
dggs |
Grid object to verify (from hexify_grid) |
TRUE (invisibly) if valid, otherwise throws an error
grid <- hexify_grid(area = 1000, aperture = 3)
dgverify(grid) # Should pass silently
# Invalid grid will throw error
bad_grid <- list(aperture = 5)
try(dgverify(bad_grid)) # Will error
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.