| hexify_index_to_lonlat | R Documentation |
Returns the cell center coordinates for a given index.
hexify_index_to_lonlat(
index,
aperture = 3L,
index_type = c("auto", "z3", "z7", "zorder")
)
index |
Index string |
aperture |
Aperture (3, 4, or 7) |
index_type |
Index encoding. Default "auto" infers from aperture. |
Named numeric vector with lon and lat in degrees
Other hierarchical index:
hexify_cell_to_index(),
hexify_compare_indices(),
hexify_default_index_type(),
hexify_get_children(),
hexify_get_parent(),
hexify_get_resolution(),
hexify_index_to_cell(),
hexify_is_valid_index_type(),
hexify_lonlat_to_index(),
hexify_z7_canonical()
coords <- hexify_index_to_lonlat("0012012", aperture = 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.