View source: R/hexify_conversions.R
| hexify_roundtrip_test | R Documentation |
Tests the accuracy of the coordinate conversion functions by converting coordinates to cells and back, measuring the distance between original and reconstructed coordinates.
hexify_roundtrip_test(grid, lon, lat, units = "km")
grid |
Grid specification |
lon |
Longitude to test |
lat |
Latitude to test |
units |
Distance units ("km" or "degrees") |
List with:
original |
Original coordinates |
cell |
Cell index |
reconstructed |
Reconstructed coordinates |
error |
Distance between original and reconstructed |
Other coordinate conversion:
hexify_cell_id_to_quad_ij(),
hexify_cell_to_icosa_tri(),
hexify_cell_to_lonlat(),
hexify_cell_to_plane(),
hexify_cell_to_quad_ij(),
hexify_cell_to_quad_xy(),
hexify_grid_cell_to_lonlat(),
hexify_grid_to_cell(),
hexify_icosa_tri_to_plane(),
hexify_icosa_tri_to_quad_ij(),
hexify_icosa_tri_to_quad_xy(),
hexify_lonlat_to_cell(),
hexify_lonlat_to_plane(),
hexify_lonlat_to_quad_ij(),
hexify_quad_ij_to_cell(),
hexify_quad_ij_to_icosa_tri(),
hexify_quad_ij_to_xy(),
hexify_quad_xy_to_cell(),
hexify_quad_xy_to_icosa_tri()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.