| hexify_world | R Documentation |
A lightweight sf object containing simplified world country borders, suitable for use as a basemap when visualizing hexagonal grids.
hexify_world
An sf object with 177 features and 15 fields:
Country short name
Country full name
Administrative name
Sovereignty
ISO 3166-1 alpha-2 country code
ISO 3166-1 alpha-3 country code
ISO 3166-1 numeric code
Continent name
UN region
UN subregion
World Bank region
Population estimate
GDP in millions USD
Income group classification
Economy type
MULTIPOLYGON geometry in 'WGS84' (EPSG:4326)
Simplified from Natural Earth 1:110m Cultural Vectors (https://www.naturalearthdata.com/)
library(sf)
# Plot the built-in world map
plot(st_geometry(hexify_world), col = "lightgray", border = "white")
# Filter by continent
europe <- hexify_world[hexify_world$continent == "Europe", ]
plot(st_geometry(europe))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.